# DTP Sites

DTP Sites is an open source blogging platform built on Node.js and the DTP ecosystem.

## Requirements

The only qualified operated system for hosting a DTP Sites suite is [Ubuntu 20.04 LTS](https://releases.ubuntu.com/20.04/). It is acceptable to run it in a virtual machine for development and testing, but it should be run as close to bare metal as can be had for production environments.

## Install Build Tools (for mediasoup support)

```sh
apt-get -y install build-essential python3-pip
```

## Install Data Tier Components

You will need MongoDB and MinIO installed and running before you can start DTP Sites web services.

1. [Install MongoDB](https://docs.mongodb.com/manual/tutorial/install-mongodb-on-ubuntu/)
2. [Install MinIO](https://docs.min.io/docs/minio-quickstart-guide.html)

Install redis:
```sh
sudo apt-get install redis
```

## Install Node Version Manager (NVM) and Node.js

```sh
wget -qO- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.1/install.sh | bash
```

## Resolve Global Node Dependencies

Yarn, Gulp, and Forever are required to be installed globally. This should be done once per developer workstation and repeated when updates are required.

```sh
nvm install --lts
npm install -g yarn gulp forever
```

## Preparing a Fresh Install

### Clone the DTP Sites Repository
```sh
cd ~/live
git clone git@git.digitaltelepresence.com:digital-telepresence/dtp-sites.git
```
### Install Required Dependencies
```sh
cd ~/live/dtp-sites
yarn
```
### Generate SSL/TLS Certificate
```sh
cd ~/live/dtp-sites/ssl
./mkcert
```
### Environment Configuration

On a new host or host image, copy `.env.default` to `.env` and edit it as necessary.

For password salt and service passwords, the `uuidgen` tool may be useful to help generate hard-to-guess passwords for use in a development environment. Something more sophisticated than a UUID should be used in production.

## Starting DTP Sites In Development Mode

1. Make sure `NODE_ENV` is set to `local`
2. Run `./start-local` in a VS Code terminal, then rename that terminal to `services`.
3. In a new VS Code terminal, run `gulp` and rename that terminal `gulp`.
4. Open https://localhost:3000 in your web browser.

You can now make changes to program source code, and the environment will automatically respond, build, pack, and re-load things as needed depending on what you did and what's open/running.

DTP Sites is a multi-tier web hosting engine built on:

- [MongoDB](https://www.mongodb.com/)
- [Redis](https://redis.io/)
- [MinIO](https://min.io/)
- [Node.js](https://nodejs.org/en/)
- [ExpressJS](http://expressjs.com/)
- [UIkit](https://getuikit.com/)

## Production Environment Information

The only qualified operated system for hosting a DTP Sites suite is [Ubuntu 20.04 LTS](https://releases.ubuntu.com/20.04/). It is acceptable to run it in a virtual machine for development and testing, but it should be run as close to bare metal as possible in production environments.

It's impossible to give 100% generic advice here, but it all depends on how large your audience is and how much they use your website. Larger, more active audiences will require a different kind of production server deployment than smaller and less active audiences.

Generally, it's possible to stack all components on one host and operate a fast site for small-to-medium audiences. The size of the host may vary, but it's possible to keep the system stacked and handle quite a large audience.

Beyond a point, you'll need to start isolating services away from each other. Storage will want it's own system(s), MongoDB will want it's own systems (plural), Redis will want it's own system(s), and the Node.js components can each start to want their own system(s).

Once you start scaling horizontally, the host requirements change a little. You will need two networks and network interfaces per host. The production network to handle public requests; and a management network for handling IPC and data-sharing among the hosts themselves.

- [MongoDB](https://docs.mongodb.com/launch-manage/)

Some useful links for learning more about hosting MinIO:

- [Quick Start](https://docs.min.io/docs/minio-quickstart-guide.html)
- [Configuration](https://docs.min.io/docs/minio-server-configuration-guide.html)

- [Docker](https://docs.min.io/docs/minio-docker-quickstart-guide.html)
- [Distributed](https://docs.min.io/docs/distributed-minio-quickstart-guide.html)
- [Monitoring](https://docs.min.io/docs/minio-monitoring-guide.html)

- [Security Overview](https://docs.min.io/docs/minio-security-overview.html)
- [TLS](https://docs.min.io/docs/how-to-secure-access-to-minio-server-with-tls.html)


Redis simply has many different documents to describe it's many different features and their requirements. I'd like to give you a summary page link, but it doesn't exist. This is that summary page. These are those links.

- [Quick Start](https://redis.io/topics/quickstart)

- [Access Control Lists](https://redis.io/topics/acl)
- [Administration](https://redis.io/topics/admin)
- [Configuration](https://redis.io/topics/config)
- [Encryption](https://redis.io/topics/encryption)
- [High Availability](https://redis.io/topics/sentinel)
- [Persistence](https://redis.io/topics/persistence)
- [Replication](https://redis.io/topics/replication)
- [Security](https://redis.io/topics/security)
- [Signals](https://redis.io/topics/signals)

## Software License

DTP Sites and the DTP Phoenix Engine and framework are licensed under the [Apache 2.0](https://spdx.org/licenses/Apache-2.0.html) open source software license. See [LICENSE](LICENSE) for more information.