// chat.js
// Copyright (C) 2022 DTP Technologies, LLC
// License: Apache-2.0

'use strict';

const path = require('path');
require('dotenv').config({ path: path.resolve(__dirname, '..', '..', '.env') });

const mongoose = require('mongoose');

const { SiteLog, SiteWorker, SiteAsync } = require(path.join(__dirname, '..', '..', 'lib', 'site-lib'));

module.rootPath = path.resolve(__dirname, '..', '..');
module.pkg = require(path.resolve(__dirname, '..', '..', 'package.json'));

module.config = {
  environment: process.env.NODE_ENV,
  root: module.rootPath,
  component: { name: 'chatWorker', slug: 'chat-worker' },
};

module.config.site = require(path.join(module.rootPath, 'config', 'site'));

class ChatWorker extends SiteWorker {

  constructor (dtp) {
    super(dtp, dtp.config.component);
  }

  async start ( ) {
    await super.start();

    await this.loadProcessor(path.join(__dirname, 'chat', 'job', 'chat-room-clear.js'));
    await this.loadProcessor(path.join(__dirname, 'chat', 'job', 'chat-room-delete.js'));

    await this.startProcessors();
  }

  async stop ( ) {
    await super.stop();
  }

  async deleteChatMessage (message) {
    const { attachment: attachmentService } = this.dtp.services;
    const ChatMessage = mongoose.model('ChatMessage');

    await SiteAsync.each(message.attachments, attachmentService.remove.bind(attachmentService), 2);
    await ChatMessage.deleteOne({ _id: message._id });
  }
}

(async ( ) => {
  try {
    module.log = new SiteLog(module, module.config.component);

    module.worker = new ChatWorker(module);
    await module.worker.start();

    module.log.info(`${module.pkg.name} v${module.pkg.version} ${module.config.component.name} started`);
  } catch (error) {
    module.log.error('failed to start worker', { component: module.config.component, error });
    process.exit(-1);
  }

})();