// venue.js
// Copyright (C) 2022 DTP Technologies, LLC
// License: Apache-2.0

'use strict';

const path = require('path');

require('dotenv').config({ path: path.resolve(__dirname, '..', '..', '.env') });

const {
  SiteLog,
  SiteWorker,
} = require(path.join(__dirname, '..', '..', 'lib', 'site-lib'));

module.rootPath = path.resolve(__dirname, '..', '..');
module.pkg = require(path.resolve(__dirname, '..', '..', 'package.json'));

module.config = {
  environment: process.env.NODE_ENV,
  root: module.rootPath,
  component: { name: 'venue', slug: 'venue' },
};

module.config.site = require(path.join(module.rootPath, 'config', 'site'));
module.config.http = require(path.join(module.rootPath, 'config', 'http'));

/**
 * This worker was mothballed in favor of just live-requesting the status from
 * the Soapbox back-end. This worker doesn't need to be started or running for
 * now. There will be uses for it, but current channel status is not one of
 * them.
 */
class VenueWorker extends SiteWorker {

  constructor (dtp) {
    super(dtp, dtp.config.component);
  }

  async start ( ) {
    await super.start();

    await this.loadProcessor(path.join(__dirname, 'venue', 'cron', 'update-channel-status.js'));
    await this.startProcessors();
  }

  async stop ( ) {
    await super.stop();
  }
}

(async ( ) => {
  try {
    module.log = new SiteLog(module, module.config.component);

    module.worker = new VenueWorker(module);
    await module.worker.start();

    module.log.info(`${module.pkg.name} v${module.pkg.version} ${module.config.component.name} started`);
  } catch (error) {
    module.log.error('failed to start worker', { component: module.config.component, error });
    process.exit(-1);
  }

})();